@@ -5,7 +5,7 @@ use Lemonldap::NG::Manager::SOAPServer;
 Lemonldap::NG::Manager::SOAPServer->start(
     configStorage => {
         type    => "File",
-        dirName => "/usr/share/doc/lemonldap-ng/examples/conf/"
+        dirName => "__CONFDIR__"
     }
 );
 
